.. Copyright (c) 2019-2024, Julien Seguinot (juseg.dev)
.. GNU General Public License v3.0+ (https://www.gnu.org/licenses/gpl-3.0.txt)

Hyoga
=====

.. image:: https://readthedocs.org/projects/hyoga/badge/?version=latest
   :target: https://hyoga.readthedocs.io
.. image:: https://github.com/juseg/hyoga/actions/workflows/tests.yaml/badge.svg
   :target: https://github.com/juseg/hyoga/actions?query=workflow%3Atests
.. image:: https://codecov.io/github/juseg/hyoga/branch/main/graph/badge.svg
   :target: https://codecov.io/github/juseg/hyoga
.. image:: https://img.shields.io/pypi/v/hyoga.svg
   :target: https://pypi.python.org/pypi/hyoga
.. image:: https://zenodo.org/badge/227465038.svg
   :target: https://zenodo.org/badge/latestdoi/227465038

Hyoga_ is a Python_ library to prepare and visualize ice-sheet model datasets.
It acts as a thin wrapper around GeoPandas_ and xarray_ for CF_-compliant
datasets on regular grids used for instance in PISM_. Hyoga (氷河) is the
Japanese word for glacier (lit. ice river). See the documentation_ for more.

.. _CF: https://cfconventions.org
.. _documentation: https://hyoga.readthedocs.io
.. _GeoPandas: https://geopandas.org
.. _Hyoga: https://hyoga.readthedocs.io
.. _PISM: https://pism.io
.. _Python: https://python.org
.. _xarray: https://xarray.pydata.org/en/stable/
